@@ -3,7 +3,7 @@ use warnings;
 
 package Git::More;
 {
-  $Git::More::VERSION = '0.021';
+  $Git::More::VERSION = '0.022';
 }
 # ABSTRACT: An extension of App::gh::Git with some goodies for hook developers.
 use parent 'App::gh::Git';
@@ -80,13 +80,11 @@ sub get_commit_msg {
 }
 
 
-sub get_affected_files {
-    my ($git, $old_commit, $new_commit, $filter) = @_;
-    my @cmd = qw/diff --cached --name-status/;
-    push @cmd, "--diff-filter=$filter" if $filter;
+sub get_diff_files {
+    my ($git, @args) = @_;
     my %affected;
-    foreach ($git->command(@cmd)) {
-	my ($status, $name) = split / /, $_, 2;
+    foreach ($git->command(diff => '--name-status', @args)) {
+	my ($status, $name) = split ' ', $_, 2;
 	$affected{$name} = $status;
     }
     return \%affected;
@@ -105,7 +103,7 @@ Git::More - An extension of App::gh::Git with some goodies for hook developers.
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 SYNOPSIS
 
@@ -178,8 +176,8 @@ it like this:
 =head2 get_current_branch
 
 This method returns the repository's current branch name, as indicated
-by the C<git branch> command. Note that its a ref shortname, i.e.,
-it's usually subintended to reside under the 'refs/heads/' ref scope.
+by the C<git branch> command. Note that its a ref short name, i.e.,
+it's usually sub-intended to reside under the 'refs/heads/' ref scope.
 
 =head2 get_commits OLDCOMMIT NEWCOMMIT
 
@@ -208,16 +206,23 @@ codes are explained in the C<git help rev-list> document):
 This method returns the commit message (aka body) of the commit
 identified by COMMIT_ID. The result is a string.
 
-=head2 get_affected_files OLDCOMMIT NEWCOMMIT [FILTER]
+=head2 get_diff_files DIFFARGS...
 
-This method returns a reference to a hash mapping every affected files
-between OLDCOMMIT and NEWCOMMIT to their affecting status. The list is
-grokked with the command C<git diff --cached --name-status>.
+This method invokes the command C<git diff --name-status> with extra
+options and arguments as passed to it. It returns a reference to a
+hash mapping every affected files their affecting status. Its purpose
+is to make it easy to grok the names of files affected by a commit or
+a sequence of commits. Please, read C<git help diff> to know
 
-The optional FILTER parameter must be a valid value for the
-C<--diff-filter> option of the C<git diff> command. You can use it to
-C<AM>, for instance, to request only files that have been Added or
-Modified.
+A common usage is to grok every file added or modified in a pre-commit
+hook:
+
+    $git->get_diff_files('--diff-filter=AM', '--cached');
+
+Another one is to grok every file added or modified in a pre-receive
+hook:
+
+    $git->get_diff_files('--diff-filter=AM', $old_commit, $new_commit);
 
 =head1 SEE ALSO
 
